# Generated by Django 4.2.6 on 2024-03-15 04:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("djf_surveys", "0012_survey_notification_to"),
    ]

    operations = [
        migrations.AddField(
            model_name="survey",
            name="success_page_content",
            field=models.TextField(
                blank=True,
                help_text="You can override success page content at here. Support HTML syntax",
                null=True,
                verbose_name="Success Page Content",
            ),
        ),
    ]
