{% load static %}
<!doctype html>
<html>
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Survey - {{ title }}</title>
    <link rel="stylesheet" href="{% static 'djf_surveys/te-starter/css/tw-elements.min.css' %}">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.5/font/bootstrap-icons.css">
    <script src="{% static 'djf_surveys/css/tailwindcss-3.3.1.js' %}"></script>
    <script src="{% static 'djf_surveys/css/tailwindcss-plugin-3.3.1.js' %}"></script>
    {% block extra_css %}{% endblock %}
</head>
<body>
    {% if messages %}
        {% for message in messages %}
            {% include 'djf_surveys/components/alert.html' %}
        {% endfor %}
    {% endif %}
    {% include 'djf_surveys/components/header_nav.html' %}
    <div class="container mx-auto">
        {% block content %} {% endblock %}
    </div>
    <script src="{% static 'djf_surveys/te-starter/js/tw-elements.umd.min.js' %}"></script>
    {% include 'djf_surveys/components/alert_js.html' %}
    {% block extra_js %}{% endblock %}
</body>
</html>