{% extends get_master_template %}
{% load djf_survey_tags static %}

{% block extra_css %}
    <link rel="stylesheet" href="{% static 'djf_surveys/te-starter/css/tw-elements.min.css' %}">
    <link rel="stylesheet" href="{% static 'djf_surveys/css/rating.css' %}"/>
{% endblock %}

{% block content %}
    <div class="max-w-screen-xl px-4 py-16 mx-auto sm:px-6 lg:px-8">
        <div class="max-w-lg mx-auto">
            <h1 class="text-2xl font-bold text-center text-blue-500 sm:text-3xl">{{ title_page }}</h1>

            <p class="max-w-md mx-auto mt-4 mb-4 text-center text-gray-500">
                {{ sub_title_page }}
            </p>

            {% include 'djf_surveys/components/card_list_answer.html' %}
        </div>
    </div>

{% endblock %}

{% block extra_js %}
    <script src="{% static 'djf_surveys/te-starter/js/tw-elements.umd.min.js' %}"></script>
{% endblock %}